@@ -15,16 +15,19 @@ for (i in 1:length(cuts)) {
    
 d.mat<- data.frame(latent,observed,trunc)  #combine into a data frame
 pairs.panels(d.mat) 
-trunc.cor<- cor(d.mat)                 #find the correlations
+trunc.cor<- cor(d.mat)                 #find the Pearson correlations
 freq <- mean(d.mat)                    #find the frequencies of scores
 
 #now, convert the upper diagonal to polychorics using John Fox's polychor and my phi2poly
-
+if(require(polycor)) {
+ #first demonstrate the poly.mat function
+ tetra <- poly.mat(d.mat[,3:7])
+ 
 for (i in 4:length(d.mat)) {
    for (j in 3:i) {
        trunc.cor[j,i]<- phi2poly(trunc.cor[i,j],freq[i],freq[j]) 
        }}
-  return(trunc.cor)
+  return(list(tetrachoric=tetra, phis=trunc.cor))} else {message("I am sorry, this function requires the polycor package")}
 
 }
 
