@@ -1,5 +1,6 @@
 "principal" <-
 function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, scores=FALSE,missing=FALSE,impute="median", digits=2) {
+   cl <- match.call()
    n <- dim(r)[2]
   
    if (n!=dim(r)[1]) {
@@ -73,11 +74,12 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, scores=FALSE,
    
      class(loadings) <- "loadings"
      
-   result <- factor.stats(r,loadings,Phi,n.obs)
+    result <- factor.stats(r,loadings,Phi,n.obs)
     class(result) <- c("psych", "principal") 
     result$fn <- "principal"
     result$loadings <- loadings
     result$Phi <- Phi
+    result$Call <- cl
     if(scores) {result$scores <- factor.scores(scale(x.matrix),loadings) }
     return(result)
    }
